@@ -7,8 +7,8 @@ The file parser that handles the parsing of POSCAR and CONTCAR files.
 # pylint: disable=no-self-use
 import numpy as np
 
-from parsevasp.poscar import Poscar, Site
 from aiida.common.constants import elements
+from parsevasp.poscar import Poscar, Site
 from aiida_vasp.parsers.file_parsers.parser import BaseFileParser
 from aiida_vasp.parsers.node_composer import NodeComposer
 from aiida_vasp.utils.aiida_utils import get_data_class
@@ -48,11 +48,15 @@ class PoscarParser(BaseFileParser):
         super(PoscarParser, self).__init__(*args, **kwargs)
         self.precision = 12
         self._structure = None
+        self.options = None
         self.init_with_kwargs(**kwargs)
 
     def _init_with_precision(self, precision):
         self.precision = precision
 
+    def _init_with_options(self, options):
+        self.options = options
+
     def _init_with_data(self, data):
         """Initialize with an AiiDA StructureData instance."""
         if isinstance(data, get_data_class('structure')):
@@ -69,9 +73,9 @@ class PoscarParser(BaseFileParser):
         """Return the parsevasp object representing the POSCAR file."""
 
         if isinstance(self._data_obj, get_data_class('structure')):
-            # _data_obj is StructurData, return the parsed version if possible.
+            # _data_obj is StructureData, return the parsed version if possible.
             try:
-                return Poscar(poscar_dict=self.aiida_to_parsevasp(self._data_obj),
+                return Poscar(poscar_dict=self.aiida_to_parsevasp(self._data_obj, options=self.options),
                               prec=self.precision,
                               conserve_order=True,
                               logger=self._logger)
@@ -105,21 +109,36 @@ class PoscarParser(BaseFileParser):
             self._structure = composer.compose('structure', quantities=['poscar-structure'])
         return self._structure
 
-    def aiida_to_parsevasp(self, structure):
+    def aiida_to_parsevasp(self, structure, options=None):
         """Convert Aiida StructureData to parsevasp's dictionary format."""
         dictionary = {}
         dictionary['comment'] = structure.label or structure.get_formula()
         dictionary['unitcell'] = np.asarray(structure.cell)
-        selective = [True, True, True]
         # As for now all Aiida-structures are in Cartesian coordinates.
         direct = False
         sites = []
-        for site in structure.sites:
-            sites.append(Site(site.kind_name, site.position, selective=selective, direct=direct, logger=self._logger))
+        _transform_to_bool = np.vectorize(self.transform_to_bool)
+        for index, site in enumerate(structure.sites):
+            if options is None:
+                _selective = [True, True, True]
+            else:
+                try:
+                    _selective = _transform_to_bool(np.array(options['positions_dof'])[index, :])
+                except KeyError:
+                    _selective = [True, True, True]
+            sites.append(Site(site.kind_name, site.position, selective=_selective, direct=direct, logger=self._logger))
 
         dictionary['sites'] = sites
         return dictionary
 
+    def transform_to_bool(self, value):
+        """Helper function to transform the dictionary from strings or integers to bools"""
+        if value in [0, 'F', 'f']:
+            return False
+        if value in [1, 'T', 't']:
+            return True
+        return True
+
 
 def parsevasp_to_aiida(poscar):
     """
