@@ -13,7 +13,9 @@ from aiida_vasp.parsers.quantity import ParsableQuantities
 """NODE_TYPES"""  # pylint: disable=pointless-string-statement
 
 NODES_TYPES = {
-    'dict': ['total_energies', 'maximum_force', 'maximum_stress', 'symmetries', 'magnetization', 'site_magnetization'],
+    'dict': [
+        'total_energies', 'maximum_force', 'maximum_stress', 'symmetries', 'magnetization', 'site_magnetization', 'notifications', 'version'
+    ],
     'array.kpoints': ['kpoints'],
     'structure': ['structure'],
     'array.trajectory': ['trajectory'],
