@@ -1,6 +1,7 @@
-""" # noqa: D205
-Delegate types
---------------
+"""
+Delegate types.
+
+---------------
 Module containing decorators and classes implementing delegate types.
 """
 from functools import update_wrapper
