@@ -1,7 +1,8 @@
 """Expose all fixtures."""
 from .data import localhost_dir, localhost, vasp_params, potentials, vasp_structure, vasp_kpoints, vasp_code, ref_incar, \
     ref_incar_vasp2w90, vasp_chgcar, vasp_wavecar, ref_retrieved, vasp_structure_poscar, temp_pot_folder, potcar_family, \
-    vasprun_parser, outcar_parser, mock_vasp, wannier_params, wannier_projections, ref_win, phonondb_run, vasp_inputs, vasp2w90_inputs
+    vasprun_parser, outcar_parser, mock_vasp, wannier_params, wannier_projections, ref_win, phonondb_run, vasp_inputs, \
+    vasp2w90_inputs, stream_parser
 from .environment import fresh_aiida_env
 from .calcs import base_calc, vasp_calc_and_ref, vasp2w90_calc_and_ref, vasp2w90_calc, vasp_calc, run_vasp_calc
 
@@ -10,5 +11,5 @@ __all__ = [
     'ref_incar', 'ref_incar_vasp2w90', 'vasp_chgcar', 'vasp_wavecar', 'ref_retrieved', 'vasp_calc_and_ref', 'vasp2w90_calc_and_ref',
     'vasp2w90_calc', 'vasp_structure_poscar', 'temp_pot_folder', 'potcar_family', 'vasprun_parser', 'outcar_parser', 'mock_vasp',
     'wannier_params', 'wannier_projections', 'ref_win', 'phonondb_run', 'base_calc', 'vasp_calc', 'vasp_inputs', 'vasp2w90_inputs',
-    'run_vasp_calc'
+    'run_vasp_calc', 'stream_parser'
 ]
