@@ -15,7 +15,7 @@ from aiida.orm import Code
 from aiida_vasp.utils.aiida_utils import get_data_class, get_data_node
 from aiida_vasp.utils.workchains import compose_exit_code
 from aiida_vasp.workchains.restart import BaseRestartWorkChain
-from aiida_vasp.utils.parameters import ParametersMassage
+from aiida_vasp.assistant.parameters import ParametersMassage, inherit_and_merge_parameters
 
 
 class VaspWorkChain(BaseRestartWorkChain):
@@ -89,6 +89,12 @@ class VaspWorkChain(BaseRestartWorkChain):
                    help="""
             If True, enable more detailed output during workchain execution.
             """)
+        spec.input('dynamics.positions_dof',
+                   valid_type=get_data_class('list'),
+                   required=False,
+                   help="""
+            Site dependent flag for selective dynamics when performing relaxation
+            """)
 
         spec.outline(
             cls.init_context,
@@ -126,19 +132,23 @@ class VaspWorkChain(BaseRestartWorkChain):
         spec.exit_code(700, 'ERROR_NO_POTENTIAL_FAMILY_NAME', message='the user did not supply a potential family name')
         spec.exit_code(701, 'ERROR_POTENTIAL_VALUE_ERROR', message='ValueError was returned from get_potcars_from_structure')
         spec.exit_code(702, 'ERROR_POTENTIAL_DO_NOT_EXIST', message='the potential does not exist')
-        spec.exit_code(703,
-                       'ERROR_INVALID_PARAMETER_DETECTED',
-                       message='the parameter massager found invalid tags in the input parameters.')
-        spec.exit_code(704,
-                       'ERROR_MISSING_PARAMETER_DETECTED',
-                       message='the parameter massager did not find expected tags in the input parameters.')
+        spec.exit_code(703, 'ERROR_IN_PARAMETER_MASSAGER', message='the exception: {exception} was thrown while massaging the parameters')
+
+    def _init_parameters(self):
+        """Collect input to the workchain in the converge namespace and put that into the parameters."""
+
+        # At some point we will replace this with possibly input checking using the PortNamespace on
+        # a dict parameter type. As such we remove the workchain input parameters as node entities. Much of
+        # the following is just a workaround until that is in place in AiiDA core.
+        parameters = inherit_and_merge_parameters(self.inputs)
+
+        return parameters
 
     def init_calculation(self):
         """Set the restart folder and set parameters tags for a restart."""
         # Check first if the calling workchain wants a restart in the same folder
         if 'restart_folder' in self.inputs:
             self.ctx.inputs.restart_folder = self.inputs.restart_folder
-
         # Then check if we the restart workchain wants a restart
         if isinstance(self.ctx.restart_calc, self._calculation):
             self.ctx.inputs.restart_folder = self.ctx.restart_calc.outputs.remote_folder
@@ -154,7 +164,7 @@ class VaspWorkChain(BaseRestartWorkChain):
     def init_inputs(self):
         """Make sure all the required inputs are there and valid, create input dictionary for calculation."""
         self.ctx.inputs = AttributeDict()
-
+        self.ctx.inputs.parameters = self._init_parameters()
         # Set the code
         self.ctx.inputs.code = self.inputs.code
 
@@ -164,17 +174,31 @@ class VaspWorkChain(BaseRestartWorkChain):
         # Set the kpoints (kpoints)
         self.ctx.inputs.kpoints = self.inputs.kpoints
 
-        # Perform inputs massage to accommodate generalization in higher lying workchains
-        # and set parameters
-        parameters_massager = ParametersMassage(self, self.inputs.parameters)
-        # Check exit codes from the parameter massager and set it if it exists
-        if parameters_massager.exit_code is not None:
-            return parameters_massager.exit_code
-        self.ctx.inputs.parameters = parameters_massager.parameters
-
         # Set settings
+        unsupported_parameters = None
         if 'settings' in self.inputs:
             self.ctx.inputs.settings = self.inputs.settings
+            # Also check if the user supplied additional tags that is not in the supported file.
+            try:
+                unsupported_parameters = self.ctx.inputs.settings.unsupported_parameters
+            except AttributeError:
+                pass
+
+        # Perform inputs massage to accommodate generalization in higher lying workchains
+        # and set parameters.
+        try:
+            parameters_massager = ParametersMassage(self.ctx.inputs.parameters, unsupported_parameters)
+        except Exception as exception:  # pylint: disable=broad-except
+            return self.exit_codes.ERROR_IN_PARAMETER_MASSAGER.format(exception=exception)  # pylint: disable=no-member
+        try:
+            # Only set if they exists
+            # Set any INCAR tags
+            self.ctx.inputs.parameters = parameters_massager.parameters.incar
+            # Set any dynamics input (currently only for selective dynamics, e.g. custom write to POSCAR)
+            self.ctx.inputs.dynamics = parameters_massager.parameters.dynamics
+            # Here we could set additional override flags, but those are not relevant for this VASP plugin
+        except AttributeError:
+            pass
 
         # Set options
         # Options is very special, not storable and should be
